(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    109877,       3113]
NotebookOptionsPosition[     44172,       1630]
NotebookOutlinePosition[    100438,       2791]
CellTagsIndexPosition[    100359,       2786]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar", "FirstSlide",
 CellTags->"SlideShowHeader",
 ExpressionUUID -> "24c7d991-436d-485d-a37a-0c17dd8dbfa2"],

Cell[TextData[{
 "Type Theory and Proofs\n\n",
 StyleBox["An exploration of ideas",
  FontSize->36]
}], "Title",
 ExpressionUUID -> "bcf2f893-4d20-4be4-96ac-fa9de8cf5374"],

Cell["\<\

Jos\[EAcute] Mart\[IAcute]n-Garc\[IAcute]a, Wolfram Research\
\>", "Subtitle",
 ExpressionUUID -> "8d0e4dc9-afce-463b-9b42-7aa652ea5853"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader",
 ExpressionUUID -> "66a19406-91f6-4e7e-bb1d-6c0d868fc1d6"],

Cell[CellGroupData[{

Cell["0a. Intro", "Section"],

Cell["\<\
\[Bullet] Type systems are important in Computer Science for static \
debugging, compilation, testing, and many other things.\
\>", "Text"],

Cell["\<\
\[Bullet] In this talk we shall explore a completely different use of type \
theory: the encoding of mathematical statements and their proofs.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["0b. Summary", "Section"],

Cell["\<\
1. Untyped lambda calculus.
2. Simply typed lambda calculus.
3. More elaborate typed lambda calculi.
4. Curry-Howard isomorphism.
5. A few more steps forward.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Conclusions", "Section"],

Cell["\<\
\[Bullet] If the type language is rich enough, it can encode mathematical \
propositions.\
\>", "Text"],

Cell["\<\
\[Bullet] Curry-Howard isomorphism: When a type \[Alpha] is interpreted as a \
proposition, then a term having type \[Alpha] represents a proof of the \
proposition. If there is no term having that type then the proposition is \
unprovable. PAT : \[OpenCurlyDoubleQuote]propositions as types, proofs as \
terms\[CloseCurlyDoubleQuote].\
\>", "Text"],

Cell["\<\
\[Bullet] The proof term can be interpreted as a collection of steps to \
perform in order to prove the given statement.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader",
 ExpressionUUID -> "587d88bb-ca1b-45e0-bdbf-0f0f87fceddc"],

Cell[CellGroupData[{

Cell["1. Untyped lambda calculus", "Section"],

Cell["\[Bullet] Abstraction:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{"LambdaFunction", "[", 
   RowBox[{"x", ",", 
    RowBox[{"x", "^", "2"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", "x"], ".", 
  SuperscriptBox["x", "2"]}]], "Output"]
}, Open  ]],

Cell["\<\
\[Bullet] Application (standard notation uses a blank, f a, instead of f[a]):\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", "a", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Lambda]", "x"], ".", 
    SuperscriptBox["x", "2"]}], ")"}], "[", "a", "]"}]], "Output"]
}, Open  ]],

Cell["\[Bullet] Beta reduction, controlled by the bound variable:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BetaReduce", "[", 
  RowBox[{"%", ",", "x"}], "]"}]], "Input"],

Cell[BoxData[
 SuperscriptBox["a", "2"]], "Output"]
}, Open  ]],

Cell["\<\
\[Bullet] A function of two variables. Use \[OpenCurlyDoubleQuote]curried\
\[CloseCurlyDoubleQuote] notation for application:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "=", 
  RowBox[{"LambdaFunction", "[", 
   RowBox[{"x", ",", "y", ",", 
    RowBox[{"x", "+", "y"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", "x"], ".", 
  RowBox[{
   SubscriptBox["\[Lambda]", "y"], ".", 
   RowBox[{"x", "+", "y"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "InputForm"}]], "Input"],

Cell["LambdaFunction[x, LambdaFunction[y, x + y]]", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "a", "]"}], "[", "b", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Lambda]", "x"], ".", 
     RowBox[{
      SubscriptBox["\[Lambda]", "y"], ".", 
      RowBox[{"x", "+", "y"}]}]}], ")"}], "[", "a", "]"}], "[", "b", 
  "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BetaReduce", "[", 
  RowBox[{"%", ",", "x"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Lambda]", "y"], ".", 
    RowBox[{"a", "+", "y"}]}], ")"}], "[", "b", "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BetaReduce", "[", 
  RowBox[{"%", ",", "y"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"a", "+", "b"}]], "Output"]
}, Open  ]],

Cell["\[Bullet] Bound variables may need renaming:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "[", "y", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Lambda]", "x"], ".", 
    RowBox[{
     SubscriptBox["\[Lambda]", "y"], ".", 
     RowBox[{"x", "+", "y"}]}]}], ")"}], "[", "y", "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BetaReduce", "[", 
  RowBox[{
   RowBox[{"g", "[", "y", "]"}], ",", "x"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", "\[FormalA]"], ".", 
  RowBox[{"\[FormalA]", "+", "y"}]}]], "Output"]
}, Open  ]],

Cell["Alpha equivalence:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LambdaFunction", "[", 
   RowBox[{"x", ",", 
    RowBox[{"x", "^", "2"}]}], "]"}], "\[TildeEqual]", 
  RowBox[{"LambdaFunction", "[", 
   RowBox[{"y", ",", 
    RowBox[{"y", "^", "2"}]}], "]"}]}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"f", ",", "g"}], "]"}]], "Input"],

Cell["\[Bullet] Beta normalization:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"LambdaFunction", "[", 
   RowBox[{"x", ",", 
    RowBox[{"LambdaFunction", "[", 
     RowBox[{"y", ",", 
      RowBox[{
       RowBox[{"LambdaFunction", "[", 
        RowBox[{"xsq", ",", 
         RowBox[{
          RowBox[{"LambdaFunction", "[", 
           RowBox[{"ysq", ",", 
            RowBox[{"xsq", "+", "ysq"}]}], "]"}], "[", 
          RowBox[{"y", "*", "y"}], "]"}]}], "]"}], "[", 
       RowBox[{"x", "*", "x"}], "]"}]}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", "x"], ".", 
  RowBox[{
   SubscriptBox["\[Lambda]", "y"], ".", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Lambda]", "xsq"], ".", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Lambda]", "ysq"], ".", 
         RowBox[{"xsq", "+", "ysq"}]}], ")"}], "[", 
       SuperscriptBox["y", "2"], "]"}]}], ")"}], "[", 
    SuperscriptBox["x", "2"], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BetaNormal", "[", "expr", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", "\[FormalA]"], ".", 
  RowBox[{
   SubscriptBox["\[Lambda]", "\[FormalB]"], ".", 
   RowBox[{
    SuperscriptBox["\[FormalA]", "2"], "+", 
    SuperscriptBox["\[FormalB]", "2"]}]}]}]], "Output"]
}, Open  ]],

Cell["An expression without normal form, running into a loop:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{
   RowBox[{"LambdaFunction", "[", 
    RowBox[{"x", ",", 
     RowBox[{"x", "[", "x", "]"}]}], "]"}], "[", 
   RowBox[{"LambdaFunction", "[", 
    RowBox[{"y", ",", 
     RowBox[{"y", "[", "y", "]"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Lambda]", "x"], ".", 
    RowBox[{"x", "[", "x", "]"}]}], ")"}], "[", 
  RowBox[{
   SubscriptBox["\[Lambda]", "y"], ".", 
   RowBox[{"y", "[", "y", "]"}]}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BetaReduce", "[", 
  RowBox[{"expr", ",", "x"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Lambda]", "y"], ".", 
    RowBox[{"y", "[", "y", "]"}]}], ")"}], "[", 
  RowBox[{
   SubscriptBox["\[Lambda]", "y"], ".", 
   RowBox[{"y", "[", "y", "]"}]}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BetaNormal", "[", "expr", "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{
  "BetaNormal","loop","\"Found beta reduction loop.\"",2,109,4,
   18971693628595661110,"Local"},
  "MessageTemplate"]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{"BetaNormal", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Lambda]", "x"], ".", 
     RowBox[{"x", "[", "x", "]"}]}], ")"}], "[", 
   RowBox[{
    SubscriptBox["\[Lambda]", "y"], ".", 
    RowBox[{"y", "[", "y", "]"}]}], "]"}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "expr", "]"}]], "Input"],

Cell["\[Bullet] Represent natural numbers and their addition:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"zero", "=", 
   RowBox[{"LambdaFunction", "[", 
    RowBox[{"f", ",", "x", ",", "x"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"one", "=", 
   RowBox[{"LambdaFunction", "[", 
    RowBox[{"f", ",", "x", ",", 
     RowBox[{"f", "[", "x", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"two", "=", 
   RowBox[{"LambdaFunction", "[", 
    RowBox[{"f", ",", "x", ",", 
     RowBox[{"f", "[", 
      RowBox[{"f", "[", "x", "]"}], "]"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"add", "=", 
   RowBox[{"LambdaFunction", "[", 
    RowBox[{"m", ",", "n", ",", "f", ",", "x", ",", 
     RowBox[{
      RowBox[{"m", "[", "f", "]"}], "[", 
      RowBox[{
       RowBox[{"n", "[", "f", "]"}], "[", "x", "]"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mult", "=", 
   RowBox[{"LambdaFunction", "[", 
    RowBox[{"m", ",", "n", ",", "f", ",", "x", ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"n", "[", "f", "]"}], "]"}], "[", "x", "]"}]}], "]"}]}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"add", "[", "one", "]"}], "[", "one", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Lambda]", "m"], ".", 
     RowBox[{
      SubscriptBox["\[Lambda]", "n"], ".", 
      RowBox[{
       SubscriptBox["\[Lambda]", "f"], ".", 
       RowBox[{
        SubscriptBox["\[Lambda]", "x"], ".", 
        RowBox[{
         RowBox[{"m", "[", "f", "]"}], "[", 
         RowBox[{
          RowBox[{"n", "[", "f", "]"}], "[", "x", "]"}], "]"}]}]}]}]}], ")"}],
    "[", 
   RowBox[{
    SubscriptBox["\[Lambda]", "f"], ".", 
    RowBox[{
     SubscriptBox["\[Lambda]", "x"], ".", 
     RowBox[{"f", "[", "x", "]"}]}]}], "]"}], "[", 
  RowBox[{
   SubscriptBox["\[Lambda]", "f"], ".", 
   RowBox[{
    SubscriptBox["\[Lambda]", "x"], ".", 
    RowBox[{"f", "[", "x", "]"}]}]}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BetaNormal", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", "\[FormalA]"], ".", 
  RowBox[{
   SubscriptBox["\[Lambda]", "\[FormalB]"], ".", 
   RowBox[{"\[FormalA]", "[", 
    RowBox[{"\[FormalA]", "[", "\[FormalB]", "]"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "\[TildeEqual]", "two"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BetaNormal", "[", 
   RowBox[{
    RowBox[{"mult", "[", "one", "]"}], "[", "zero", "]"}], "]"}], 
  "\[TildeEqual]", "zero"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"zero", ",", "one", ",", "two", ",", "add", ",", "mult"}], 
  "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader",
 ExpressionUUID -> "587d88bb-ca1b-45e0-bdbf-0f0f87fceddc"],

Cell[CellGroupData[{

Cell["2. Simply typed lambda calculus", "Section"],

Cell["\[Bullet] Indicate the type of a term:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Typed", "[", 
  RowBox[{"a", ",", "\[Alpha]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"a", ":", "\[Alpha]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LambdaFunction", "[", 
  RowBox[{
   RowBox[{"Typed", "[", 
    RowBox[{"a", ",", "\[Alpha]"}], "]"}], ",", "a"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", 
   RowBox[{"a", ":", "\[Alpha]"}]], ".", "a"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LambdaFunction", "[", 
  RowBox[{
   RowBox[{"Typed", "[", 
    RowBox[{"a", ",", "b", ",", "\[Alpha]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "a", "]"}], "[", "b", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", 
   RowBox[{"a", ":", "\[Alpha]"}]], ".", 
  RowBox[{
   SubscriptBox["\[Lambda]", 
    RowBox[{"b", ":", "\[Alpha]"}]], ".", 
   RowBox[{
    RowBox[{"f", "[", "a", "]"}], "[", "b", "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "InputForm"}]], "Input"],

Cell["\<\
LambdaFunction[Typed[a, \[Alpha]], LambdaFunction[Typed[b, \[Alpha]], \
f[a][b]]]\
\>", "Output"]
}, Open  ]],

Cell["\[Bullet] The \[OpenCurlyDoubleQuote]arrow\[CloseCurlyDoubleQuote] \
type. Add parenthesis for clarity:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrowType", "[", 
  RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(", "\[Alpha]", "\[Rule]", "\[Beta]", ")"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrowType", "[", 
  RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(", "\[Alpha]", "\[Rule]", 
  RowBox[{"(", "\[Beta]", "\[Rule]", "\[Gamma]", ")"}], ")"}]], "Output"]
}, Open  ]],

Cell["\[Bullet] Finding types:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LambdaFunction", "[", 
  RowBox[{
   RowBox[{"Typed", "[", 
    RowBox[{"x", ",", "\[Alpha]"}], "]"}], ",", "x"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", 
   RowBox[{"x", ":", "\[Alpha]"}]], ".", "x"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(", "\[Alpha]", "\[Rule]", "\[Alpha]", ")"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LambdaFunction", "[", 
  RowBox[{
   RowBox[{"Typed", "[", 
    RowBox[{"x", ",", "\[Alpha]"}], "]"}], ",", "y"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", 
   RowBox[{"x", ":", "\[Alpha]"}]], ".", "y"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"Typed", "[", 
     RowBox[{"y", ",", "\[Beta]"}], "]"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(", "\[Alpha]", "\[Rule]", "\[Beta]", ")"}]], "Output"]
}, Open  ]],

Cell["\<\
\[Bullet] Self-application is essentially forbidden in typed lambda calculus:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", 
  RowBox[{
   RowBox[{"x", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Typed", "[", 
     RowBox[{"x", ",", "\[Alpha]"}], "]"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{
  "Type","comp",
   "\"Cannot apply function \\!\\(\\*RowBox[{\\\"x\\\"}]\\) of type \
\\!\\(\\*RowBox[{\\\"\[Alpha]\\\"}]\\) on argument \
\\!\\(\\*RowBox[{\\\"x\\\"}]\\) of type \
\\!\\(\\*RowBox[{\\\"\[Alpha]\\\"}]\\).\"",2,131,5,18971693628595661110,
   "Local"},
  "MessageTemplate"]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{"Type", "[", 
  RowBox[{
   RowBox[{"x", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ":", "\[Alpha]"}], "}"}], ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Output"]
}, Open  ]],

Cell["\[Bullet] A slightly nontrivial case:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LambdaFunction", "[", 
  RowBox[{
   RowBox[{"Typed", "[", 
    RowBox[{"h", ",", 
     RowBox[{"ArrowType", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}], ",", 
   RowBox[{"Typed", "[", 
    RowBox[{"x", ",", "\[Alpha]"}], "]"}], ",", 
   RowBox[{"h", "[", "x", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", 
   RowBox[{"h", ":", 
    RowBox[{"(", "\[Alpha]", "\[Rule]", "\[Beta]", ")"}]}]], ".", 
  RowBox[{
   SubscriptBox["\[Lambda]", 
    RowBox[{"x", ":", "\[Alpha]"}]], ".", 
   RowBox[{"h", "[", "x", "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{"(", "\[Alpha]", "\[Rule]", "\[Beta]", ")"}], "\[Rule]", 
  RowBox[{"(", "\[Alpha]", "\[Rule]", "\[Beta]", ")"}], ")"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader",
 ExpressionUUID -> "587d88bb-ca1b-45e0-bdbf-0f0f87fceddc"],

Cell[CellGroupData[{

Cell["3. More elaborate type calculi", "Section"],

Cell["\<\
\[Bullet] Terms and types are asymmetrically treated. The term language is \
powerful, but the type language is not yet powerful enough.\
\>", "Text"],

Cell["\[Bullet] Types have type StarType.", "Text"],

Cell[CellGroupData[{

Cell[BoxData["StarType"], "Input"],

Cell[BoxData["*"], "Output"]
}, Open  ]],

Cell["\<\
\[Bullet] We can say that in LambdaFunction[x, M] the term M depends on the \
term x. We now want to generalize in three directions:

\t- Terms that depend on types (second order typed lambda calculus, \
polimorphism).

\t- Types that depend on types.

\t- Types that depend on terms.

  Barendregt cube (names of intermediate cases not shown). \[Lambda]C is the \
Calculus of Constructions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"arrow", "[", 
   RowBox[{"p1_", ",", "p2_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Norm", "[", 
      RowBox[{"p1", "-", "p2"}], "]"}], ">", "1"}], ",", "Nothing", ",", 
    RowBox[{"Arrow", "[", 
     RowBox[{"{", 
      RowBox[{"p1", ",", "p2"}], "}"}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Graphics3D", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"arrow", "@@@", 
      RowBox[{"Subsets", "[", 
       RowBox[{
        RowBox[{"Tuples", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", "3"}], "]"}], ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\[Lambda]\[Rule]\>\"", ",", "Larger"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1"}], ",", 
         RowBox[{"-", "0.1"}], ",", "0"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\[Lambda]C\>\"", ",", "Larger"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.1", ",", "1.1", ",", "1"}], "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}]}], "Input",
 CellID->71614074],

Cell[BoxData[
 Graphics3DBox[{{Arrow3DBox[{{0, 0, 0}, {0, 0, 1}}], 
    Arrow3DBox[{{0, 0, 0}, {0, 1, 0}}], Arrow3DBox[{{0, 0, 0}, {1, 0, 0}}], 
    Arrow3DBox[{{0, 0, 1}, {0, 1, 1}}], Arrow3DBox[{{0, 0, 1}, {1, 0, 1}}], 
    Arrow3DBox[{{0, 1, 0}, {0, 1, 1}}], Arrow3DBox[{{0, 1, 0}, {1, 1, 0}}], 
    Arrow3DBox[{{0, 1, 1}, {1, 1, 1}}], Arrow3DBox[{{1, 0, 0}, {1, 0, 1}}], 
    Arrow3DBox[{{1, 0, 0}, {1, 1, 0}}], Arrow3DBox[{{1, 0, 1}, {1, 1, 1}}], 
    Arrow3DBox[{{1, 1, 0}, {1, 1, 1}}]}, Text3DBox[
    StyleBox["\<\"\[Lambda]\[Rule]\"\>",
     StripOnInput->False,
     FontSize->Larger], {-0.1, -0.1, 0}], Text3DBox[
    StyleBox["\<\"\[Lambda]C\"\>",
     StripOnInput->False,
     FontSize->Larger], {1.1, 1.1, 1}]},
  Boxed->False]], "Output"]
}, Open  ]],

Cell["\<\
There is then the Calculus of Inductive Constructions, used by LEAN and Coq.\
\>", "Text"],

Cell["\[Bullet] Terms that depend on types:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LambdaFunction", "[", 
  RowBox[{
   RowBox[{"Typed", "[", 
    RowBox[{"\[Alpha]", ",", "StarType"}], "]"}], ",", 
   RowBox[{"Typed", "[", 
    RowBox[{"x", ",", "\[Alpha]"}], "]"}], ",", "x"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", 
   RowBox[{"\[Alpha]", ":", "*"}]], ".", 
  RowBox[{
   SubscriptBox["\[Lambda]", 
    RowBox[{"x", ":", "\[Alpha]"}]], ".", "x"}]}]], "Output"]
}, Open  ]],

Cell["Its type is represented with a Pi-abstraction:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalPi]", 
   RowBox[{"\[Alpha]", ":", "*"}]], ".", 
  RowBox[{"(", "\[Alpha]", "\[Rule]", "\[Alpha]", ")"}]}]], "Output"]
}, Open  ]],

Cell["It is a type:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", "%", "]"}]], "Input"],

Cell[BoxData["*"], "Output"]
}, Open  ]],

Cell["\[Bullet] Types that depend on types:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LambdaFunction", "[", 
  RowBox[{
   RowBox[{"Typed", "[", 
    RowBox[{"\[Alpha]", ",", "StarType"}], "]"}], ",", "\[Alpha]"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", 
   RowBox[{"\[Alpha]", ":", "*"}]], ".", "\[Alpha]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(", "*", "\[Rule]", "*", ")"}]], "Output"]
}, Open  ]],

Cell["\[Bullet] Types that depend on terms:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LambdaFunction", "[", 
  RowBox[{
   RowBox[{"Typed", "[", 
    RowBox[{"x", ",", "\[Beta]"}], "]"}], ",", "\[Alpha]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", 
   RowBox[{"x", ":", "\[Beta]"}]], ".", "\[Alpha]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"Typed", "[", 
     RowBox[{"\[Alpha]", ",", "StarType"}], "]"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(", "\[Beta]", "\[Rule]", "*", ")"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader",
 ExpressionUUID -> "587d88bb-ca1b-45e0-bdbf-0f0f87fceddc"],

Cell[CellGroupData[{

Cell["4. Curry-Howard isomorphism", "Section"],

Cell["\<\
Separate two forms of the star type, one for sets and another for \
propositions. Always clear from the context.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\t\t", GridBox[{
    {
     RowBox[{"       ", 
      RowBox[{
       StyleBox["Type",
        FontWeight->"Bold"], 
       StyleBox[" ",
        FontWeight->"Bold"], 
       StyleBox["Theory",
        FontWeight->"Bold"], 
       StyleBox[
        RowBox[{
         StyleBox[" ",
          FontWeight->"Bold"], "     "}]]}]}], 
     StyleBox["Logic",
      FontWeight->"Bold"]},
    {
     RowBox[{"S", ":", 
      SubscriptBox["*", "sets"]}], 
     RowBox[{"S", "  ", "is", "  ", "a", "  ", "set"}]},
    {
     RowBox[{"A", ":", 
      SubscriptBox["*", "props"]}], 
     RowBox[{"A", "  ", "is", "  ", "a", "  ", "proposition"}]},
    {
     RowBox[{"a", ":", "S"}], 
     RowBox[{"a", "\[Element]", "S"}]},
    {
     RowBox[{"p", " ", ":", " ", "A"}], 
     RowBox[{"p", "  ", "proves", "  ", "A"}]},
    {
     RowBox[{
      RowBox[{"P", ":", "S"}], "\[Rule]", 
      SubscriptBox["*", "props"]}], 
     RowBox[{"     ", 
      RowBox[{
      "P", " ", "is", "  ", "a", "  ", "predicate", "  ", "on", "  ", "S", 
       "     "}]}]},
    {
     RowBox[{"A", "\[Rule]", "B"}], 
     RowBox[{"A", "\[Implies]", "B"}]},
    {
     RowBox[{
      SubscriptBox["\[CapitalPi]", 
       RowBox[{"a", ":", "S"}]], " ", ".", " ", 
      RowBox[{"P", "[", "a", "]"}]}], 
     RowBox[{
      SubscriptBox["\[ForAll]", 
       RowBox[{"a", "\[Element]", "S"}]], 
      RowBox[{"P", "[", "a", "]"}]}]},
    {"...", "..."}
   },
   GridBoxDividers->{
    "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
     "RowsIndexed" -> {}}]}]], "Text",
 FontSize->18],

Cell["\[Bullet] Example:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LambdaFunction", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Typed", "[", 
    RowBox[{"z", ",", 
     RowBox[{"PiType", "[", 
      RowBox[{
       RowBox[{"Typed", "[", 
        RowBox[{"x", ",", "S"}], "]"}], ",", 
       RowBox[{"Typed", "[", 
        RowBox[{"y", ",", "S"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Q", "[", "x", "]"}], "[", "y", "]"}]}], "]"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Typed", "[", 
    RowBox[{"u", ",", "S"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"z", "[", "u", "]"}], "[", "u", "]"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", 
   RowBox[{"z", ":", 
    RowBox[{
     SubscriptBox["\[CapitalPi]", 
      RowBox[{"x", ":", "S"}]], ".", 
     RowBox[{
      SubscriptBox["\[CapitalPi]", 
       RowBox[{"y", ":", "S"}]], ".", 
      RowBox[{
       RowBox[{"Q", "[", "x", "]"}], "[", "y", "]"}]}]}]}]], ".", 
  RowBox[{
   SubscriptBox["\[Lambda]", 
    RowBox[{"u", ":", "S"}]], ".", 
   RowBox[{
    RowBox[{"z", "[", "u", "]"}], "[", "u", "]"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
The following statement is true because it is inhabited (by the previous \
term):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Typed", "[", 
      RowBox[{"S", ",", "StarType"}], "]"}], ",", 
     RowBox[{"Typed", "[", 
      RowBox[{"Q", ",", 
       RowBox[{"ArrowType", "[", 
        RowBox[{"S", ",", "S", ",", "StarType"}], "]"}]}], "]"}]}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   SubscriptBox["\[CapitalPi]", 
    RowBox[{"x", ":", "S"}]], ".", 
   RowBox[{
    SubscriptBox["\[CapitalPi]", 
     RowBox[{"y", ":", "S"}]], ".", 
    RowBox[{
     RowBox[{"Q", "[", "x", "]"}], "[", "y", "]"}]}]}], "\[Rule]", 
  RowBox[{
   SubscriptBox["\[CapitalPi]", 
    RowBox[{"u", ":", "S"}]], ".", 
   RowBox[{
    RowBox[{"Q", "[", "u", "]"}], "[", "u", "]"}]}], ")"}]], "Output"]
}, Open  ]],

Cell["\<\
The Type function (\[OpenCurlyDoubleQuote]type \
checker\[CloseCurlyDoubleQuote]) is doing two things at the same time:

\t\[Bullet] It is computing the final type, which represents the theorem \
being proved.

\t\[Bullet] It is checking the integrity of the proof term. If the proof term \
had any problem, it would not type-check, or would type check to another true \
statement.

In the Calculus of Constructions, type-checking is simple and always \
decidable. Term-finding is equivalent to proving theorems, and it is very \
difficult in general. This is where the theorem proof assistants are of great \
help.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader",
 ExpressionUUID -> "587d88bb-ca1b-45e0-bdbf-0f0f87fceddc"],

Cell[CellGroupData[{

Cell["5. A few more steps forward", "Section"],

Cell["\<\
\[Bullet] What about other logical constructions, like And? It is possible to \
construct them from Implies and ForAll. For instance: \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Equivalent", "[", 
  RowBox[{
   RowBox[{"And", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"ForAll", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Implies", "[", 
      RowBox[{
       RowBox[{"Implies", "[", 
        RowBox[{"p", ",", 
         RowBox[{"Implies", "[", 
          RowBox[{"q", ",", "x"}], "]"}]}], "]"}], ",", "x"}], "]"}]}], 
    "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p", "&&", "q"}], "\[Equivalent]", 
  RowBox[{
   SubscriptBox["\[ForAll]", "x"], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"p", "\[Implies]", 
       RowBox[{"(", 
        RowBox[{"q", "\[Implies]", "x"}], ")"}]}], ")"}], "\[Implies]", "x"}],
     ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BooleanTable", "[", 
  RowBox[{"%", ",", "p", ",", "q"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"True", ",", 
     RowBox[{
      SubscriptBox["\[Exists]", "x"], 
      RowBox[{"!", "x"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Exists]", "x"], 
      RowBox[{"!", "x"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Exists]", "x"], 
      RowBox[{"!", "x"}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{
   RowBox[{"Exists", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Not", "[", "x", "]"}]}], "]"}], "\[Rule]", "True"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"True", ",", "True"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"True", ",", "True"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
However, this is complicated to use. It is better to introduce a new term \
whose type is precisely And[p, q].\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", 
  RowBox[{
   RowBox[{"AndIntro", "[", 
    RowBox[{"a", ",", "b"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Typed", "[", 
      RowBox[{"a", ",", "\[Alpha]"}], "]"}], ",", 
     RowBox[{"Typed", "[", 
      RowBox[{"b", ",", "\[Beta]"}], "]"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Alpha]", "&&", "\[Beta]"}]], "Output"]
}, Open  ]],

Cell["\<\
If a and b are respective proofs of \[Alpha] and \[Beta], then AndIntro[a, b] \
is the proof of And[\[Alpha], \[Beta]].\
\>", "Text"],

Cell["\<\
\[Bullet] It is convenient to introduce syntactic sugar for some of our \
constructions. These names follow Lean\[CloseCurlyQuote]s terminology.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assume", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Typed", "[", 
    RowBox[{"H", ",", 
     RowBox[{"And", "[", 
      RowBox[{"p", ",", "q"}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HaveFrom", "[", 
     RowBox[{
      RowBox[{"Typed", "[", 
       RowBox[{"Hp", ",", "p"}], "]"}], ",", 
      RowBox[{"AndElimLeft", "[", "H", "]"}]}], "]"}], "@", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"HaveFrom", "[", 
      RowBox[{
       RowBox[{"Typed", "[", 
        RowBox[{"Hq", ",", "q"}], "]"}], ",", 
       RowBox[{"AndElimRight", "[", "H", "]"}]}], "]"}], "@", 
     "\[IndentingNewLine]", 
     RowBox[{"AndIntro", "[", 
      RowBox[{"Hq", ",", "Hp"}], "]"}]}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", 
   RowBox[{"H", ":", 
    RowBox[{"p", "&&", "q"}]}]], ".", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Lambda]", 
      RowBox[{"Hp", ":", "p"}]], ".", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Lambda]", 
         RowBox[{"Hq", ":", "q"}]], ".", 
        RowBox[{"AndIntro", "[", 
         RowBox[{"Hq", ",", "Hp"}], "]"}]}], ")"}], "[", 
      RowBox[{"AndElimRight", "[", "H", "]"}], "]"}]}], ")"}], "[", 
   RowBox[{"AndElimLeft", "[", "H", "]"}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{"p", "&&", "q"}], "\[Rule]", 
  RowBox[{"q", "&&", "p"}], ")"}]], "Output"]
}, Open  ]],

Cell["\<\
\[Bullet] The logic we obtain from lambda calculus is the so-called \
\[OpenCurlyDoubleQuote]intuitionistic logic\[CloseCurlyDoubleQuote], which \
does not contain the law of the excluded middle. In order to recover \
classical logic we need to add it separately:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Type", "[", 
   RowBox[{
    RowBox[{"ExcludedMiddle", "[", "prop_", "]"}], ",", "__"}], "]"}], "^:=", 
  
  RowBox[{"Or", "[", 
   RowBox[{"prop", ",", 
    RowBox[{"Not", "[", "prop", "]"}]}], "]"}]}]], "Input"],

Cell["\<\
For example now we can show double negation elimination. It is not possible \
to show it without the law of the excluded middle.\
\>", "Text"],

Cell["\[Bullet] A more complicated case:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assume", "[", "\[IndentingNewLine]", 
  RowBox[{"EquivalentIntro", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Assume", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Typed", "[", 
       RowBox[{"H", ",", 
        RowBox[{"And", "[", 
         RowBox[{"p", ",", 
          RowBox[{"Or", "[", 
           RowBox[{"q", ",", "r"}], "]"}]}], "]"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"HaveFrom", "[", 
        RowBox[{
         RowBox[{"Typed", "[", 
          RowBox[{"Hp", ",", "p"}], "]"}], ",", 
         RowBox[{"AndElimLeft", "[", "H", "]"}]}], "]"}], "@", 
       "\[IndentingNewLine]", 
       RowBox[{"OrElim", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"AndElimRight", "[", "H", "]"}], ",", "\[IndentingNewLine]", 
         
         RowBox[{"Assume", "[", 
          RowBox[{
           RowBox[{"Typed", "[", 
            RowBox[{"Hq", ",", "q"}], "]"}], ",", 
           RowBox[{"ShowFrom", "[", 
            RowBox[{
             RowBox[{"Or", "[", 
              RowBox[{
               RowBox[{"And", "[", 
                RowBox[{"p", ",", "q"}], "]"}], ",", 
               RowBox[{"And", "[", 
                RowBox[{"p", ",", "r"}], "]"}]}], "]"}], ",", 
             RowBox[{"OrIntroLeft", "[", 
              RowBox[{
               RowBox[{"AndIntro", "[", 
                RowBox[{"Hp", ",", "Hq"}], "]"}], ",", 
               RowBox[{"And", "[", 
                RowBox[{"p", ",", "r"}], "]"}]}], "]"}]}], "]"}]}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Assume", "[", 
          RowBox[{
           RowBox[{"Typed", "[", 
            RowBox[{"Hr", ",", "r"}], "]"}], ",", 
           RowBox[{"ShowFrom", "[", 
            RowBox[{
             RowBox[{"Or", "[", 
              RowBox[{
               RowBox[{"And", "[", 
                RowBox[{"p", ",", "q"}], "]"}], ",", 
               RowBox[{"And", "[", 
                RowBox[{"p", ",", "r"}], "]"}]}], "]"}], ",", 
             RowBox[{"OrIntroRight", "[", 
              RowBox[{
               RowBox[{"AndIntro", "[", 
                RowBox[{"Hp", ",", "Hr"}], "]"}], ",", 
               RowBox[{"And", "[", 
                RowBox[{"p", ",", "q"}], "]"}]}], "]"}]}], "]"}]}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Assume", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Typed", "[", 
       RowBox[{"H", ",", 
        RowBox[{"Or", "[", 
         RowBox[{
          RowBox[{"And", "[", 
           RowBox[{"p", ",", "q"}], "]"}], ",", 
          RowBox[{"And", "[", 
           RowBox[{"p", ",", "r"}], "]"}]}], "]"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"OrElim", "[", "\[IndentingNewLine]", 
       RowBox[{"H", ",", "\[IndentingNewLine]", 
        RowBox[{"Assume", "[", 
         RowBox[{
          RowBox[{"Typed", "[", 
           RowBox[{"Hpq", ",", 
            RowBox[{"And", "[", 
             RowBox[{"p", ",", "q"}], "]"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"HaveFrom", "[", 
            RowBox[{
             RowBox[{"Typed", "[", 
              RowBox[{"Hp", ",", "p"}], "]"}], ",", 
             RowBox[{"AndElimLeft", "[", "Hpq", "]"}]}], "]"}], "@", 
           RowBox[{
            RowBox[{"HaveFrom", "[", 
             RowBox[{
              RowBox[{"Typed", "[", 
               RowBox[{"Hq", ",", "q"}], "]"}], ",", 
              RowBox[{"AndElimRight", "[", "Hpq", "]"}]}], "]"}], "@", 
            RowBox[{"ShowFrom", "[", 
             RowBox[{
              RowBox[{"And", "[", 
               RowBox[{"p", ",", 
                RowBox[{"Or", "[", 
                 RowBox[{"q", ",", "r"}], "]"}]}], "]"}], ",", 
              RowBox[{"AndIntro", "[", 
               RowBox[{"Hp", ",", 
                RowBox[{"OrIntroLeft", "[", 
                 RowBox[{"Hq", ",", "r"}], "]"}]}], "]"}]}], "]"}]}]}]}], 
         "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Assume", "[", 
         RowBox[{
          RowBox[{"Typed", "[", 
           RowBox[{"Hpr", ",", 
            RowBox[{"And", "[", 
             RowBox[{"p", ",", "r"}], "]"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"HaveFrom", "[", 
            RowBox[{
             RowBox[{"Typed", "[", 
              RowBox[{"Hp", ",", "p"}], "]"}], ",", 
             RowBox[{"AndElimLeft", "[", "Hpr", "]"}]}], "]"}], "@", 
           RowBox[{
            RowBox[{"HaveFrom", "[", 
             RowBox[{
              RowBox[{"Typed", "[", 
               RowBox[{"Hr", ",", "r"}], "]"}], ",", 
              RowBox[{"AndElimRight", "[", "Hpr", "]"}]}], "]"}], "@", 
            RowBox[{"ShowFrom", "[", 
             RowBox[{
              RowBox[{"And", "[", 
               RowBox[{"p", ",", 
                RowBox[{"Or", "[", 
                 RowBox[{"q", ",", "r"}], "]"}]}], "]"}], ",", 
              RowBox[{"AndIntro", "[", 
               RowBox[{"Hp", ",", 
                RowBox[{"OrIntroRight", "[", 
                 RowBox[{"Hr", ",", "q"}], "]"}]}], "]"}]}], "]"}]}]}]}], 
         "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"EquivalentIntro", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Lambda]", 
     RowBox[{"H", ":", 
      RowBox[{"p", "&&", 
       RowBox[{"(", 
        RowBox[{"q", "||", "r"}], ")"}]}]}]], ".", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Lambda]", 
        RowBox[{"Hp", ":", "p"}]], ".", 
       RowBox[{"OrElim", "[", 
        RowBox[{
         RowBox[{"AndElimRight", "[", "H", "]"}], ",", 
         RowBox[{
          SubscriptBox["\[Lambda]", 
           RowBox[{"Hq", ":", "q"}]], ".", 
          RowBox[{
           RowBox[{"OrIntroLeft", "[", 
            RowBox[{
             RowBox[{"AndIntro", "[", 
              RowBox[{"Hp", ",", "Hq"}], "]"}], ",", 
             RowBox[{"p", "&&", "r"}]}], "]"}], ":", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"p", "&&", "q"}], ")"}], "||", 
            RowBox[{"(", 
             RowBox[{"p", "&&", "r"}], ")"}]}]}]}], ",", 
         RowBox[{
          SubscriptBox["\[Lambda]", 
           RowBox[{"Hr", ":", "r"}]], ".", 
          RowBox[{
           RowBox[{"OrIntroRight", "[", 
            RowBox[{
             RowBox[{"AndIntro", "[", 
              RowBox[{"Hp", ",", "Hr"}], "]"}], ",", 
             RowBox[{"p", "&&", "q"}]}], "]"}], ":", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"p", "&&", "q"}], ")"}], "||", 
            RowBox[{"(", 
             RowBox[{"p", "&&", "r"}], ")"}]}]}]}]}], "]"}]}], ")"}], "[", 
     RowBox[{"AndElimLeft", "[", "H", "]"}], "]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Lambda]", 
     RowBox[{"H", ":", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "&&", "q"}], ")"}], "||", 
       RowBox[{"(", 
        RowBox[{"p", "&&", "r"}], ")"}]}]}]], ".", 
    RowBox[{"OrElim", "[", 
     RowBox[{"H", ",", 
      RowBox[{
       SubscriptBox["\[Lambda]", 
        RowBox[{"Hpq", ":", 
         RowBox[{"p", "&&", "q"}]}]], ".", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Lambda]", 
           RowBox[{"Hp", ":", "p"}]], ".", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Lambda]", 
              RowBox[{"Hq", ":", "q"}]], ".", 
             RowBox[{
              RowBox[{"AndIntro", "[", 
               RowBox[{"Hp", ",", 
                RowBox[{"OrIntroLeft", "[", 
                 RowBox[{"Hq", ",", "r"}], "]"}]}], "]"}], ":", 
              RowBox[{"p", "&&", 
               RowBox[{"(", 
                RowBox[{"q", "||", "r"}], ")"}]}]}]}], ")"}], "[", 
           RowBox[{"AndElimRight", "[", "Hpq", "]"}], "]"}]}], ")"}], "[", 
        RowBox[{"AndElimLeft", "[", "Hpq", "]"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Lambda]", 
        RowBox[{"Hpr", ":", 
         RowBox[{"p", "&&", "r"}]}]], ".", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Lambda]", 
           RowBox[{"Hp", ":", "p"}]], ".", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Lambda]", 
              RowBox[{"Hr", ":", "r"}]], ".", 
             RowBox[{
              RowBox[{"AndIntro", "[", 
               RowBox[{"Hp", ",", 
                RowBox[{"OrIntroRight", "[", 
                 RowBox[{"Hr", ",", "q"}], "]"}]}], "]"}], ":", 
              RowBox[{"p", "&&", 
               RowBox[{"(", 
                RowBox[{"q", "||", "r"}], ")"}]}]}]}], ")"}], "[", 
           RowBox[{"AndElimRight", "[", "Hpr", "]"}], "]"}]}], ")"}], "[", 
        RowBox[{"AndElimLeft", "[", "Hpr", "]"}], "]"}]}]}], "]"}]}]}], 
  "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Type", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"Typed", "[", 
     RowBox[{"p", ",", "q", ",", "r", ",", "StarType"}], "]"}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p", "&&", 
   RowBox[{"(", 
    RowBox[{"q", "||", "r"}], ")"}]}], "\[Equivalent]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"p", "&&", "q"}], ")"}], "||", 
   RowBox[{"(", 
    RowBox[{"p", "&&", "r"}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader",
 ExpressionUUID -> "587d88bb-ca1b-45e0-bdbf-0f0f87fceddc"],

Cell[CellGroupData[{

Cell["6. Conclusions", "Section"],

Cell["\<\
\[Bullet] We have shown prototype-level ideas of how to handle types, \
motivated by logic and theorem manipulation.\
\>", "Text"],

Cell["\<\
\[Bullet] If the type language is rich enough, it can encode mathematical \
propositions.\
\>", "Text"],

Cell["\<\
\[Bullet] Curry-Howard isomorphism: When a type \[Alpha] is interpreted as a \
proposition, then a term having type \[Alpha] represents a proof of the \
proposition. If there is no term having that type then the proposition is \
unprovable. PAT : \[OpenCurlyDoubleQuote]propositions as types, proofs as \
terms\[CloseCurlyDoubleQuote].\
\>", "Text"],

Cell["\<\
\[Bullet] The proof term can be interpreted as a collection of steps to \
perform in order to prove the given statement. In practical terms this may be \
too complex, and more compact ways of expressing the proofs will be needed.\
\>", "Text"],

Cell["\<\
\[Bullet] Finding a proof is difficult, and proof assistants like LEAN are \
very useful, and are becoming increasingly better in automating some steps. \
Checking a proof is easy. We just need to type-check the proof. As long as \
the type-checker code is well tested, this is very safe.\
\>", "Text"],

Cell["\<\
\[Bullet] A good reference: \[OpenCurlyDoubleQuote]Type Theory and Formal \
Proof: An Introduction\[CloseCurlyDoubleQuote], Nederpelt & Geuvers, CUP 2014.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1388, 855},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
TaggingRules->{"SlideShow" -> True},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell["Style Environment Names", "Section"], 
      Cell[
       StyleData[All, "Working"]], 
      Cell[
       StyleData[All, "Presentation"], MenuSortingValue -> None], 
      Cell[
       StyleData[All, "Condensed"], MenuSortingValue -> None], 
      Cell[
       StyleData[All, "SlideShow"]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Notebook Options Settings", "Section"], 
      Cell[
       StyleData["Notebook"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.739193, 0.750317, 0.747173]}]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Title and Section Cells", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], ShowCellBracket -> Automatic, ShowGroupOpener -> 
          False, CellMargins -> {{100, 100}, {14, 50}}, 
          CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> False, 
          CellFrameMargins -> {{20, 20}, {20, 20}}, DefaultNewInlineCellStyle -> 
          "None", InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, TextAlignment -> Center, LineSpacing -> {1, 0}, 
          LanguageCategory -> "NaturalLanguage", CounterIncrements -> "Title",
           CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
            "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
          "Arial", FontSize -> 45, FontWeight -> "Bold", FontSlant -> "Plain",
           FontTracking -> "Plain", 
          FontVariations -> {
           "Outline" -> False, "Shadow" -> False, "StrikeThrough" -> False, 
            "Underline" -> False}, FontColor -> 
          RGBColor[
           0.8156862745098039, 0.07058823529411765, 0.07058823529411765], 
          Background -> None, FontVariations -> {"Masked" -> False}], 
         Cell[
          StyleData["Title", "Presentation", StyleDefinitions -> None], 
          CellMargins -> {{55, 3}, {14, 125}}, LineSpacing -> {1, 5}, 
          FontSize -> 48], 
         Cell[
          StyleData[
          "Title", "SlideShow", StyleDefinitions -> 
           StyleData["Title", "Presentation"]], 
          CellMargins -> {{100, 100}, {52, 105}}, FontColor -> GrayLevel[1]], 
         
         Cell[
          StyleData["Title", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{2, 0}, {0, 20}}, FontSize -> 24]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subtitle"], ShowCellBracket -> Automatic, 
          CellMargins -> {{0, 0}, {0, 5}}, 
          CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> False,
           DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, TextAlignment -> Center, LanguageCategory -> 
          "NaturalLanguage", CounterIncrements -> "Subtitle", 
          CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
            "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Arial", 
          FontSize -> 27, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> RGBColor[0.4, 0.4, 0.4], Background -> None], 
         Cell[
          StyleData["Subtitle", "Presentation", StyleDefinitions -> None], 
          CellMargins -> {{58, 0}, {0, 5}}, FontSize -> 36], 
         Cell[
          StyleData[
          "Subtitle", "SlideShow", StyleDefinitions -> StyleData["Subtitle"]],
           CellMargins -> {{0, 0}, {0, 5}}, FontSize -> 27, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.9019607843137255, 0.9019607843137255]], 
         Cell[
          StyleData["Subtitle", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{2, 0}, {0, 5}}, FontSize -> 18, Background -> 
          GrayLevel[1]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubtitle", StyleDefinitions -> StyleData["Subtitle"]],
           CellMargins -> {{0, 0}, {30, 5}}, FontSize -> 24, FontSlant -> 
          "Plain", FontColor -> RGBColor[0.4, 0.4, 0.4]], 
         Cell[
          StyleData["Subsubtitle", "Presentation"], FontSize -> 24], 
         Cell[
          StyleData[
          "Subsubtitle", "SlideShow", StyleDefinitions -> 
           StyleData["Subsubtitle"]], CellMargins -> {{0, 0}, {10, 5}}, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.9019607843137255, 0.9019607843137255]], 
         Cell[
          StyleData["Subsubtitle", "Printout"], FontSize -> 14]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0.2, 0}}, 
          ShowGroupOpener -> False, CellMargins -> {{60, 50}, {7, 25}}, 
          FontSize -> 36, FontWeight -> "Plain", FontColor -> 
          RGBColor[
           0.8156862745098039, 0.07058823529411765, 0.07058823529411765]], 
         Cell[
          StyleData["Section", "Presentation"], 
          CellFrame -> {{0, 0}, {0.2, 0}}, 
          CellMargins -> {{58, 50}, {7, 35}}], 
         Cell[
          StyleData[
          "Section", "SlideShow", StyleDefinitions -> 
           StyleData["Section", "Presentation"]], 
          CellMargins -> {{58, 50}, {10, 35}}], 
         Cell[
          StyleData["Section", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {4, 22}}, FontSize -> 20]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellDingbat -> None, ShowGroupOpener -> 
          False, CellMargins -> {{60, Inherited}, {0, 15}}, 
          CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
          False, DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsection", 
          CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
          "Helvetica", FontSize -> 24, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> RGBColor[0.4, 0.4, 0.4]], 
         Cell[
          StyleData["Subsection", "Presentation"], ShowGroupOpener -> True, 
          WholeCellGroupOpener -> True, CellMargins -> {{60, 50}, {0, 20}}, 
          LineSpacing -> {1, 0}, FontFamily -> "Helvetica"], 
         Cell[
          StyleData["Subsection", "SlideShow"], ShowGroupOpener -> True, 
          WholeCellGroupOpener -> True, CellMargins -> {{60, 50}, {8, 12}}, 
          LineSpacing -> {1, 0}, FontFamily -> "Helvetica"], 
         Cell[
          StyleData["Subsection", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {0, 17}}, FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], CellDingbat -> None, ShowGroupOpener -> 
          False, CellMargins -> {{60, Inherited}, {0, 15}}, 
          CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
          False, DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsubsection", FontFamily -> "Helvetica", 
          FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> RGBColor[0.4, 0.4, 0.4]], 
         Cell[
          StyleData["Subsubsection", "Presentation"], ShowGroupOpener -> True,
           WholeCellGroupOpener -> True, CellMargins -> {{60, 50}, {0, 20}}, 
          LineSpacing -> {1, 0}], 
         Cell[
          StyleData[
          "Subsubsection", "SlideShow", StyleDefinitions -> 
           StyleData["Subsubsection", "Presentation"]]], 
         Cell[
          StyleData["Subsubsection", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {0, 22}}, FontSize -> 14]}, Closed]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Body Text", "Section"], 
      Cell[
       CellGroupData[{
         Cell["Standard", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{60, 10}, {7, 7}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 3}, CounterIncrements -> "Text",
              FontFamily -> "Helvetica", FontSize -> 12], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{60, 50}, {10, 10}}, FontSize -> 17], 
            Cell[
             StyleData[
             "Text", "SlideShow", StyleDefinitions -> 
              StyleData["Text", "Presentation"]]], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{2, 2}, {6, 6}}, 
             TextJustification -> 0.5, Hyphenation -> True, FontSize -> 10]}, 
           Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Display", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> 
             Cell["\[FilledSmallCircle]", FontWeight -> "Bold"], 
             ShowGroupOpener -> False, CellMargins -> {{84, 10}, {7, 7}}, 
             ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
             CounterIncrements -> "Item"], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{124, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "Item", "SlideShow", StyleDefinitions -> 
              StyleData["Item", "Presentation"]]], 
            Cell[
             StyleData["Item", "Printout"], 
             CellMargins -> {{39, 2}, {0, 6}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem", StyleDefinitions -> StyleData["Item"]], 
             CellMargins -> {{108, 10}, {7, 7}}, ReturnCreatesNewCell -> True,
              CellGroupingRules -> {"GroupTogetherNestedGrouping", 15150}, 
             CounterIncrements -> "Subitem"], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{146, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "Subitem", "SlideShow", StyleDefinitions -> 
              StyleData["Subitem", "Presentation"]]], 
            Cell[
             StyleData["Subitem", "Printout"], 
             CellMargins -> {{67, 2}, {0, 6}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered", StyleDefinitions -> StyleData["Text"]],
              CellDingbat -> Cell[
               TextData[{
                 CounterBox["ItemNumbered"], "."}]], ShowGroupOpener -> False,
              CellMargins -> {{84, 10}, {7, 7}}, ReturnCreatesNewCell -> True,
              CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
             CounterIncrements -> "ItemNumbered"], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{124, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "ItemNumbered", "SlideShow", StyleDefinitions -> 
              StyleData["ItemNumbered", "Presentation"]]], 
            Cell[
             StyleData["ItemNumbered", "Printout"], 
             CellMargins -> {{39, 2}, {0, 6}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "SubitemNumbered", StyleDefinitions -> 
              StyleData["ItemNumbered"]], CellDingbat -> Cell[
               TextData[{
                 CounterBox["SubitemNumbered", CounterFunction :> (Part[
                    CharacterRange["a", "z"], #]& )], "."}]], 
             CellMargins -> {{108, 10}, {7, 7}}, ReturnCreatesNewCell -> True,
              CellGroupingRules -> {"GroupTogetherNestedGrouping", 15150}, 
             CounterIncrements -> "SubitemNumbered"], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{146, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "SubitemNumbered", "SlideShow", StyleDefinitions -> 
              StyleData["SubitemNumbered", "Presentation"]]], 
            Cell[
             StyleData["SubitemNumbered", "Printout"], 
             CellMargins -> {{67, 2}, {0, 6}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "ItemParagraph", StyleDefinitions -> StyleData["Item"]], 
             CellDingbat -> None, CellMargins -> {{84, 10}, {7, 7}}, 
             ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15100}, 
             CounterIncrements -> "ItemParagraph"], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{124, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "ItemParagraph", "SlideShow", StyleDefinitions -> 
              StyleData["ItemParagraph", "Presentation"]]], 
            Cell[
             StyleData["ItemParagraph", "Printout"], 
             CellMargins -> {{39, 2}, {0, 6}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "SubitemParagraph", StyleDefinitions -> StyleData["Subitem"]], 
             CellDingbat -> None, ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15200}, 
             CounterIncrements -> "SubitemParagraph"], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"]], 
            Cell[
             StyleData[
             "SubitemParagraph", "SlideShow", StyleDefinitions -> 
              StyleData["SubitemParagraph", "Presentation"]]], 
            Cell[
             StyleData["SubitemParagraph", "Printout"]]}, Closed]]}, Open]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Formulas and Programming", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"]], 
         Cell[
          StyleData["DisplayFormula", "Presentation"], 
          CellMargins -> {{60, Inherited}, {Inherited 1.5, Inherited 1.5}}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "DisplayFormula", "SlideShow", StyleDefinitions -> 
           StyleData["DisplayFormula", "Presentation"]]], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, FontSize -> 
          10]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}]]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered"], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Presentation"], 
          CellMargins -> {{60, Inherited}, {Inherited 1.5, Inherited 1.5}}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "DisplayFormulaNumbered", "SlideShow", StyleDefinitions -> 
           StyleData["DisplayFormulaNumbered", "Presentation"]]], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{39, Inherited}, {Inherited, Inherited}}]}, 
        Closed]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Inline Formatting", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InlineFormula"]], 
         Cell[
          StyleData["InlineFormula", "Presentation"], FontSize -> 17], 
         Cell[
          StyleData[
          "InlineFormula", "SlideShow", StyleDefinitions -> 
           StyleData["InlineFormula", "Presentation"]]], 
         Cell[
          StyleData["InlineFormula", "Printout"]]}, Closed]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Input and Output Cells", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], ShowCellBracket -> True, ShowGroupOpener -> 
          False, CellMargins -> {{103, 10}, {5, 7}}, 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.734936, 0.713848, 0.694041]}, Evaluatable -> 
          True, CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
          True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
          DefaultFormatType -> DefaultInputFormatType, 
          "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", FontWeight -> "Bold"], 
         Cell[
          StyleData["Input", "Presentation"], 
          CellMargins -> {{110, 50}, {8, 10}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "Input", "SlideShow", StyleDefinitions -> 
           StyleData["Input", "Presentation"]]], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{39, 0}, {4, 6}}, 
          LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], ShowCellBracket -> True, ShowGroupOpener -> 
          False, CellMargins -> {{103, 10}, {7, 7}}, 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.734936, 0.713848, 0.694041]}, Evaluatable -> 
          True, CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", MenuSortingValue -> 1550, FontWeight -> 
          "Bold"], 
         Cell[
          StyleData["InputOnly", "Presentation"], 
          CellMargins -> {{110, Inherited}, {8, 10}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "InputOnly", "SlideShow", StyleDefinitions -> 
           StyleData["InputOnly", "Presentation"]]], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{39, 0}, {4, 6}}, 
          LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], ShowCellBracket -> True, 
          CellMargins -> {{103, 10}, {7, 5}}, 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.734936, 0.713848, 0.694041]}, 
          CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping", 
          CellHorizontalScrolling -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, DefaultFormatType -> 
          DefaultOutputFormatType, "TwoByteSyntaxCharacterAutoReplacement" -> 
          True, HyphenationOptions -> {
           "HyphenationCharacter" -> "\[Continuation]"}, 
          AutoItalicWords -> {}, LanguageCategory -> None, FormatType -> 
          InputForm, CounterIncrements -> "Output"], 
         Cell[
          StyleData["Output", "Presentation"], 
          CellMargins -> {{110, 50}, {10, 8}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "Output", "SlideShow", StyleDefinitions -> 
           StyleData["Output", "Presentation"]]], 
         Cell[
          StyleData["Output", "Printout"], CellMargins -> {{39, 0}, {6, 4}}, 
          FontSize -> 9]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Code"], CellMargins -> {{103, 10}, {5, 10}}], 
         Cell[
          StyleData["Code", "Presentation"], 
          CellMargins -> {{110, 50}, {8, 10}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "Code", "SlideShow", StyleDefinitions -> 
           StyleData["Code", "Presentation"]]], 
         Cell[
          StyleData["Code", "Printout"], CellMargins -> {{39, 0}, {4, 6}}, 
          LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], 
          CellMargins -> {{103, Inherited}, {Inherited, Inherited}}, FontSize -> 
          14], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{70, Inherited}, {Inherited 1.5, Inherited 1.5}}, 
          FontSize -> 17, Magnification -> Inherited 1.5], 
         Cell[
          StyleData[
          "Print", "SlideShow", StyleDefinitions -> 
           StyleData["Print", "Presentation"]]], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{39, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "WolframAlphaShortInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{98, 10}, {5, 7}}, EvaluationMode -> 
          "WolframAlphaShort", 
          CellEventActions -> {"ReturnKeyDown" :> FrontEndTokenExecute[
              EvaluationNotebook[], "HandleShiftReturn"]}, 
          CellFrameLabels -> {{
             Cell[
              BoxData[
               DynamicBox[
                FEPrivate`FrontEndResource["WABitmaps", "Equal"]]], 
              CellBaseline -> Baseline], None}, {None, None}}, FormatType -> 
          TextForm, FontFamily -> "Helvetica"], 
         Cell[
          StyleData["WolframAlphaShortInput", "Presentation"], 
          CellMargins -> {{107, 50}, {8, 10}}], 
         Cell[
          StyleData[
          "WolframAlphaShortInput", "SlideShow", StyleDefinitions -> 
           StyleData["WolframAlphaShortInput", "Presentation"]]], 
         Cell[
          StyleData["WolframAlphaShortInput", "Printout"], 
          CellFrameLabelMargins -> 3]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "WolframAlphaLong", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{100, 10}, {5, 7}}, 
          StyleKeyMapping -> {
           "=" -> "Input", "Backspace" -> "WolframAlphaShort"}, 
          EvaluationMode -> "WolframAlphaLong", 
          CellEventActions -> {"ReturnKeyDown" :> FrontEndTokenExecute[
              EvaluationNotebook[], "HandleShiftReturn"]}, 
          CellFrameLabels -> {{
             Cell[
              BoxData[
               DynamicBox[
                FEPrivate`FrontEndResource["WABitmaps", "SpikeyEqual"]]]], 
             None}, {None, None}}, DefaultFormatType -> TextForm, FormatType -> 
          TextForm, FontFamily -> "Helvetica"], 
         Cell[
          StyleData["WolframAlphaLong", "Presentation"], 
          CellMargins -> {{107, 50}, {8, 10}}], 
         Cell[
          StyleData[
          "WolframAlphaLong", "SlideShow", StyleDefinitions -> 
           StyleData["WolframAlphaLong", "Presentation"]], 
          CellMargins -> {{107, 50}, {8, 10}}], 
         Cell[
          StyleData["WolframAlphaLong", "Printout"], CellFrameLabelMargins -> 
          3]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Program"], CellMargins -> {{60, 4}, {6, 8}}], 
         Cell[
          StyleData["Program", "Presentation"], 
          CellMargins -> {{60, 50}, {8, 10}}, LineSpacing -> {1, 0}, FontSize -> 
          17], 
         Cell[
          StyleData[
          "Program", "SlideShow", StyleDefinitions -> 
           StyleData["Program", "Presentation"]]], 
         Cell[
          StyleData["Program", "Printout"], CellMargins -> {{2, 0}, {0, 8}}, 
          FontSize -> 10]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"]], 
         Cell[
          StyleData["CellLabel", "Presentation"], FontSize -> 12], 
         Cell[
          StyleData[
          "CellLabel", "SlideShow", StyleDefinitions -> 
           StyleData["CellLabel", "Presentation"]]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ManipulateLabel"]], 
         Cell[
          StyleData["ManipulateLabel", "Presentation"], FontSize -> 15], 
         Cell[
          StyleData[
          "ManipulateLabel", "SlideShow", StyleDefinitions -> 
           StyleData["ManipulateLabel", "Presentation"]]], 
         Cell[
          StyleData["ManipulateLabel", "Printout"], FontSize -> 8]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GraphicsLabel"]], 
         Cell[
          StyleData["GraphicsLabel", "Presentation"], FontSize -> 14], 
         Cell[
          StyleData[
          "GraphicsLabel", "SlideShow", StyleDefinitions -> 
           StyleData["GraphicsLabel", "Presentation"]]], 
         Cell[
          StyleData["GraphicsLabel", "Printout"], FontSize -> 8]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Graphics3DLabel"]], 
         Cell[
          StyleData["Graphics3DLabel", "Presentation"], FontSize -> 14], 
         Cell[
          StyleData[
          "Graphics3DLabel", "SlideShow", StyleDefinitions -> 
           StyleData["Graphics3DLabel", "Presentation"]]], 
         Cell[
          StyleData["Graphics3DLabel", "Printout"], FontSize -> 8]}, 
        Closed]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Styles for SlideShow", "Section", 
       CellChangeTimes -> {{3.514665148412793*^9, 3.5146651505550737`*^9}}], 
      Cell[
       StyleData["slideshowheader"], ShowCellBracket -> False, 
       CellMargins -> {{0, 0}, {0, -2}}, Evaluatable -> False, 
       CellHorizontalScrolling -> False, PageBreakBelow -> False, 
       CellFrameMargins -> 0, ImageMargins -> {{0, 0}, {0, 0}}, 
       ImageRegion -> {{0, 1}, {0, 1}}, Magnification -> 1, Background -> 
       GrayLevel[1], CellPadding -> 0, CellFramePadding -> 0], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["hidefromslideshowgraphic"], ShowCellBracket -> False, 
          CellMargins -> {{0, 0}, {0, 0}}, Evaluatable -> False, 
          CellHorizontalScrolling -> False, PageBreakBelow -> False, 
          CellFrameMargins -> 0, ImageMargins -> {{0, 0}, {0, 0}}, 
          ImageRegion -> {{0, 1}, {0, 1}}, Magnification -> 1, Background -> 
          None, CellPadding -> 0], 
         Cell[
          StyleData["hidefromslideshowgraphic", "SlideShow"], ShowCellBracket -> 
          False, CellElementSpacings -> {
           "CellMinHeight" -> 0, "ClosedCellHeight" -> 0, 
            "ClosedGroupTopMargin" -> 0}, CellOpen -> False, 
          CellHorizontalScrolling -> False], 
         Cell[
          StyleData["hidefromslideshowgraphic", "Printout"], Magnification -> 
          0.6]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["slideshowheader2"], ShowCellBracket -> False, 
          CellMargins -> {{0, 0}, {0, 0}}, Evaluatable -> False, 
          CellHorizontalScrolling -> False, PageBreakBelow -> False, 
          ImageMargins -> {{0, 0}, {0, 0}}, ImageRegion -> {{0, 1}, {0, 1}}, 
          Magnification -> 1, Background -> GrayLevel[1]], 
         Cell[
          StyleData["ConferenceGraphicCell", "SlideShow"], ShowCellBracket -> 
          False, CellElementSpacings -> {
           "CellMinHeight" -> 0, "ClosedCellHeight" -> 0, 
            "ClosedGroupTopMargin" -> 0}, CellOpen -> False, 
          CellHorizontalScrolling -> True], 
         Cell[
          StyleData["slideshowheader", "Printout"], FontSize -> 8, 
          Magnification -> 0.75]}, Closed]], 
      Cell[
       StyleData[
       "ConferenceGraphicCellSlideShowOnly", StyleDefinitions -> 
        StyleData["ConferenceCellGraphic"]], ShowCellBracket -> False, 
       CellMargins -> 0, 
       CellElementSpacings -> {
        "CellMinHeight" -> 0, "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 
         0}, CellOpen -> False], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SlideShowNavigationBar"], Editable -> True, Selectable -> 
          False, CellFrame -> 0, ShowGroupOpener -> False, 
          CellMargins -> {{0, 0}, {3, 3}}, CellOpen -> True, CellFrameMargins -> 
          0, CellFrameColor -> None, Background -> None], 
         Cell[
          StyleData["SlideShowNavigationBar", "Printout"], PageBreakAbove -> 
          Automatic]}, Closed]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Styles for Slide Show Environment Documents", "Section", 
       CellChangeTimes -> {{3.559592561220532*^9, 3.559592575768806*^9}, 
         3.559652073182283*^9}], 
      Cell[
       StyleData["FirstSlide"], 
       PrivateCellOptions -> {
        "PagewiseNotebookBaseStyle" -> {
          FrontEnd`BackgroundAppearance -> FrontEnd`CurrentValue[
             FrontEnd`EvaluationNotebook[], {
             FrontEnd`UnknownOptions, presentertemplt`firstslideimage}]}}]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September 21, 2016)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"],
presentertemplt`firstslideimage -> Image[CompressedData["
1:eJzt3UmudOtVreFDUqBIF5BL0AKqFKkaIcq2MBYVI9lIiF7QEMDkeZ7n0CNz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  "], "Byte", ColorSpace -> "RGB", Interleaving -> 
  True]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[580, 22, 137, 2, 0, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1079, 42, 123, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[2572, 100, 123, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[12333, 513, 123, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[17441, 730, 123, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[22973, 938, 123, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[27736, 1110, 123, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[42590, 1584, 123, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 99627, 2766}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 137, 2, 0, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[720, 26, 171, 5, 317, "Title"],
Cell[894, 33, 148, 4, 68, "Subtitle"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1079, 42, 123, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1227, 48, 28, 0, 100, "Section"],
Cell[1258, 50, 149, 3, 38, "Text"],
Cell[1410, 55, 166, 3, 38, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1613, 63, 30, 0, 100, "Section"],
Cell[1646, 65, 182, 6, 130, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1865, 76, 33, 0, 100, "Section"],
Cell[1901, 78, 113, 3, 38, "Text"],
Cell[2017, 83, 359, 6, 61, "Text"],
Cell[2379, 91, 144, 3, 38, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2572, 100, 123, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[2720, 106, 45, 0, 100, "Section"],
Cell[2768, 108, 38, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[2831, 112, 139, 4, 40, "Input"],
Cell[2973, 118, 104, 3, 42, "Output"]
}, Open  ]],
Cell[3092, 124, 103, 3, 38, "Text"],
Cell[CellGroupData[{
Cell[3220, 131, 54, 1, 40, "Input"],
Cell[3277, 134, 160, 5, 50, "Output"]
}, Open  ]],
Cell[3452, 142, 75, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[3552, 146, 86, 2, 40, "Input"],
Cell[3641, 150, 51, 1, 42, "Output"]
}, Open  ]],
Cell[3707, 154, 149, 3, 38, "Text"],
Cell[CellGroupData[{
Cell[3881, 161, 149, 4, 40, "Input"],
Cell[4033, 167, 158, 5, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4228, 177, 58, 1, 40, "Input"],
Cell[4289, 180, 61, 0, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4387, 185, 82, 2, 40, "Input"],
Cell[4472, 189, 255, 9, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4764, 203, 86, 2, 40, "Input"],
Cell[4853, 207, 159, 5, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5049, 217, 86, 2, 40, "Input"],
Cell[5138, 221, 50, 1, 40, "Output"]
}, Open  ]],
Cell[5203, 225, 60, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[5288, 229, 54, 1, 40, "Input"],
Cell[5345, 232, 218, 7, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5600, 244, 115, 3, 40, "Input"],
Cell[5718, 249, 121, 3, 49, "Output"]
}, Open  ]],
Cell[5854, 255, 34, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[5913, 259, 241, 7, 40, "Input"],
Cell[6157, 268, 31, 0, 40, "Output"]
}, Open  ]],
Cell[6203, 271, 81, 2, 40, "Input"],
Cell[6287, 275, 45, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[6357, 279, 509, 14, 40, "Input"],
Cell[6869, 295, 467, 15, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7373, 315, 66, 1, 40, "Input"],
Cell[7442, 318, 246, 7, 53, "Output"]
}, Open  ]],
Cell[7703, 328, 71, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[7799, 332, 276, 8, 40, "Input"],
Cell[8078, 342, 247, 8, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8362, 355, 89, 2, 40, "Input"],
Cell[8454, 359, 247, 8, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8738, 372, 66, 1, 40, "Input"],
Cell[8807, 375, 167, 4, 50, "Message"],
Cell[8977, 381, 291, 9, 44, "Output"]
}, Open  ]],
Cell[9283, 393, 61, 1, 40, "Input"],
Cell[9347, 396, 71, 0, 38, "Text"],
Cell[9421, 398, 540, 16, 95, "Input"],
Cell[9964, 416, 566, 17, 68, "Input"],
Cell[CellGroupData[{
Cell[10555, 437, 88, 2, 40, "Input"],
Cell[10646, 441, 780, 26, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11463, 472, 63, 1, 40, "Input"],
Cell[11529, 475, 238, 6, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11804, 486, 63, 1, 40, "Input"],
Cell[11870, 489, 31, 0, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11938, 494, 171, 5, 40, "Input"],
Cell[12112, 501, 31, 0, 40, "Output"]
}, Open  ]],
Cell[12158, 504, 126, 3, 40, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12333, 513, 123, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[12481, 519, 50, 0, 100, "Section"],
Cell[12534, 521, 54, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[12613, 525, 88, 2, 40, "Input"],
Cell[12704, 529, 57, 1, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12798, 535, 155, 4, 40, "Input"],
Cell[12956, 541, 111, 3, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13104, 549, 224, 6, 40, "Input"],
Cell[13331, 557, 256, 8, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13624, 570, 58, 1, 40, "Input"],
Cell[13685, 573, 107, 3, 54, "Output"]
}, Open  ]],
Cell[13807, 579, 119, 1, 38, "Text"],
Cell[CellGroupData[{
Cell[13951, 584, 98, 2, 40, "Input"],
Cell[14052, 588, 79, 1, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14168, 594, 115, 2, 40, "Input"],
Cell[14286, 598, 125, 2, 40, "Output"]
}, Open  ]],
Cell[14426, 603, 40, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[14491, 607, 155, 4, 40, "Input"],
Cell[14649, 613, 111, 3, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14797, 621, 57, 1, 40, "Input"],
Cell[14857, 624, 80, 1, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14974, 630, 155, 4, 40, "Input"],
Cell[15132, 636, 111, 3, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15280, 644, 170, 5, 40, "Input"],
Cell[15453, 651, 79, 1, 40, "Output"]
}, Open  ]],
Cell[15547, 655, 103, 3, 38, "Text"],
Cell[CellGroupData[{
Cell[15675, 662, 200, 6, 40, "Input"],
Cell[15878, 670, 337, 8, 50, "Message"],
Cell[16218, 680, 195, 6, 40, "Output"]
}, Open  ]],
Cell[16428, 689, 53, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[16506, 693, 331, 9, 40, "Input"],
Cell[16840, 704, 273, 8, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17150, 717, 57, 1, 40, "Input"],
Cell[17210, 720, 170, 3, 40, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17441, 730, 123, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[17589, 736, 49, 0, 100, "Section"],
Cell[17641, 738, 160, 3, 38, "Text"],
Cell[17804, 743, 51, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[17880, 747, 34, 0, 40, "Input"],
Cell[17917, 749, 28, 0, 40, "Output"]
}, Open  ]],
Cell[17960, 752, 415, 13, 222, "Text"],
Cell[CellGroupData[{
Cell[18400, 769, 1423, 42, 176, "Input",
 CellID->71614074],
Cell[19826, 813, 754, 14, 382, "Output"]
}, Open  ]],
Cell[20595, 830, 100, 2, 38, "Text"],
Cell[20698, 834, 53, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[20776, 838, 237, 6, 40, "Input"],
Cell[21016, 846, 197, 6, 42, "Output"]
}, Open  ]],
Cell[21228, 855, 62, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[21315, 859, 57, 1, 40, "Input"],
Cell[21375, 862, 167, 4, 42, "Output"]
}, Open  ]],
Cell[21557, 869, 29, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[21611, 873, 57, 1, 40, "Input"],
Cell[21671, 876, 28, 0, 40, "Output"]
}, Open  ]],
Cell[21714, 879, 53, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[21792, 883, 172, 5, 40, "Input"],
Cell[21967, 890, 118, 3, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22122, 898, 57, 1, 40, "Input"],
Cell[22182, 901, 66, 1, 40, "Output"]
}, Open  ]],
Cell[22263, 905, 53, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[22341, 909, 161, 4, 40, "Input"],
Cell[22505, 915, 117, 3, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22659, 923, 178, 5, 40, "Input"],
Cell[22840, 930, 72, 1, 40, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22973, 938, 123, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[23121, 944, 46, 0, 100, "Section"],
Cell[23170, 946, 136, 3, 38, "Text"],
Cell[23309, 951, 1594, 56, 260, "Text"],
Cell[24906, 1009, 34, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[24965, 1013, 646, 18, 149, "Input"],
Cell[25614, 1033, 486, 16, 49, "Output"]
}, Open  ]],
Cell[26115, 1052, 105, 3, 38, "Text"],
Cell[CellGroupData[{
Cell[26245, 1059, 350, 11, 40, "Input"],
Cell[26598, 1072, 435, 14, 43, "Output"]
}, Open  ]],
Cell[27048, 1089, 639, 15, 199, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27736, 1110, 123, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[27884, 1116, 46, 0, 100, "Section"],
Cell[27933, 1118, 158, 3, 38, "Text"],
Cell[CellGroupData[{
Cell[28116, 1125, 410, 13, 40, "Input"],
Cell[28529, 1140, 326, 11, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28892, 1156, 98, 2, 40, "Input"],
Cell[28993, 1160, 405, 15, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29435, 1180, 174, 5, 40, "Input"],
Cell[29612, 1187, 183, 6, 40, "Output"]
}, Open  ]],
Cell[29810, 1196, 134, 3, 38, "Text"],
Cell[CellGroupData[{
Cell[29969, 1203, 327, 10, 40, "Input"],
Cell[30299, 1215, 64, 1, 40, "Output"]
}, Open  ]],
Cell[30378, 1219, 143, 3, 38, "Text"],
Cell[30524, 1224, 168, 3, 38, "Text"],
Cell[CellGroupData[{
Cell[30717, 1231, 791, 23, 176, "Input"],
Cell[31511, 1256, 576, 18, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32124, 1279, 57, 1, 40, "Input"],
Cell[32184, 1282, 114, 3, 40, "Output"]
}, Open  ]],
Cell[32313, 1288, 287, 5, 61, "Text"],
Cell[32603, 1295, 248, 8, 40, "Input"],
Cell[32854, 1305, 152, 3, 38, "Text"],
Cell[33009, 1310, 50, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[33084, 1314, 5316, 135, 635, "Input"],
Cell[38403, 1451, 3632, 104, 163, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42072, 1560, 194, 6, 40, "Input"],
Cell[42269, 1568, 260, 9, 40, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42590, 1584, 123, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[42738, 1590, 33, 0, 100, "Section"],
Cell[42774, 1592, 140, 3, 38, "Text"],
Cell[42917, 1597, 113, 3, 38, "Text"],
Cell[43033, 1602, 359, 6, 61, "Text"],
Cell[43395, 1610, 253, 4, 61, "Text"],
Cell[43651, 1616, 312, 5, 61, "Text"],
Cell[43966, 1623, 178, 3, 38, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

